@@ -29,11 +29,4 @@ class TensorBoard:
         return not self.writer is None
 
 
-def normalize_seq_length(seq, length):
-    return np.tile(
-        np.array(seq),
-        int(np.ceil(length / len(seq)))
-    )[:length].tolist()
-
-
 default_board = TensorBoard()
